@@ -95,6 +95,11 @@ class ImportOpendict:
         self.insert_or_replace_entry(yaml_doc, entry)
 
     def xml_workaround(self, s):
+        # 잘못된 XML 수정
+        s = s.replace(' ', ' ')
+        s = s.replace('', ' ')
+        s = s.replace('', '')
+        s = re.sub('.', '', s)
         return s
 
     def sanitize_word(self, word):
@@ -265,6 +270,8 @@ class ImportOpendict:
                 rec['종류'] = item.text
             elif item.tag == 'definition':
                 rec['뜻풀이'] = item.text
+            elif item.tag == 'definition_original':
+                rec['원뜻풀이'] = item.text
             elif item.tag == 'cat_info':
                 for subitem in item:
                     if subitem.tag == 'cat':
