@@ -9,14 +9,11 @@ import yaml
 from jamo import *
 
 class ProcessYamlDocs:
-    def __init__(self, yaml_dir):
-        self.entries_dir = entries_dir
+    def __init__(self, yaml_filename):
+        self.yaml_filename = yaml_filename
 
     def run(self):
-        filenames = glob.glob(os.path.join(self.entries_dir, '*.yaml'))
-        filenames.sort()
-        for filename in filenames:
-            self.process_file(filename)
+        self.process_file(self.yaml_filename)
 
     def process_file(self, filename):
         print('Processing %s...' % filename)
@@ -62,7 +59,7 @@ class ProcessYamlDocs:
     def process_doc_krdict(self, input, output):
         if input['의미'][0]['뜻풀이'].startswith('→'):
             output['제외'] = '틀린 말'
-        elif input['품사'] in ['어미', '접사', '조사']:
+        elif input['품사'] in ['어미', '접사']:
             output['제외'] = '해당 품사 아님'
         else:
             word = input['표제어']
@@ -82,7 +79,7 @@ class ProcessYamlDocs:
 
             # 보조용언 타입
             if pos.startswith('보조 '):
-                clue = input['의미'][0]['의미 참고']
+                clue = input['의미'][0]['참고']
                 detected = self.detect_aux_verb_type(word, clue)
                 props += detected
 
@@ -95,6 +92,30 @@ class ProcessYamlDocs:
                 if '주제 및 상황 범주' in input and input['주제 및 상황 범주'] == '개념 > 세는 말':
                     props.append('단위명사')
 
+            # 조사 문법
+            if pos == '조사':
+                clues = []
+                if '참고' in input:
+                    for sentence in input['참고'].split('.'):
+                        sentence = sentence.strip()
+                        if len(sentence) > 0:
+                            clues.append(sentence)
+                for m in input['의미']:
+                    if '참고' in m:
+                        for sentence in m['참고'].split('.'):
+                            sentence = sentence.strip()
+                            if len(sentence) > 0:
+                                clues.append(sentence)
+                if len(clues) == 0:
+                    # 문법이 없으면 일반적인 체언 뒤에 붙는 것으로 가정한다
+                    output['조사 조합'] = ['체언']
+                else:
+                    josa_combinations = self.detect_josa_combination_krdict(clues)
+                    if len(josa_combinations) > 0:
+                        output['조사 조합'] = josa_combinations
+                    else:
+                        output['제외'] = '조사 문법 정보 부족'
+
             if len(props) > 0:
                 props.sort()
                 if '속성' not in output:
@@ -373,11 +394,110 @@ class ProcessYamlDocs:
                 return True
         return False
 
+    def detect_josa_combination_krdict(self, clues):
+        prefix_list = []
+        if len(clues) == 0:
+            # 아무 정보가 없으면 모든 체언 뒤에 붙는 걸로 취급
+            prefix_list.append('체언')
+            return prefix_list
+
+        for clue in clues:
+            used = False
+
+            if clue.startswith('주로 '):
+                continue
+
+            if '나타내는 ' in clue:
+                s = clue.split('나타내는 ')[1]
+            elif '나타내는, ' in clue:
+                s = clue.split('나타내는, ')[1]
+            else:
+                s = clue
+
+            if s.startswith('‘ㄹ’을 제외한 받침 있는 '):
+                prefix_list.append('ㄹ 제외한 받침 있음')
+                s = s[len('‘ㄹ’을 제외한 받침 있는 '):]
+            elif s.startswith('받침이 없거나 ‘ㄹ’ 받침으로 끝나는 '):
+                prefix_list.append('받침 없거나 ㄹ 받침')
+                s = s[len('받침이 없거나 ‘ㄹ’ 받침으로 끝나는 '):]
+            elif s.startswith('받침이 없거나 ‘ㄹ’ 받침인 '):
+                prefix_list.append('받침 없거나 ㄹ 받침')
+                s = s[len('받침이 없거나 ‘ㄹ’ 받침인 '):]
+            elif s.startswith('받침이 없거나 ‘ㄹ’, ‘ㅆ’, ‘ㅄ’ 받침인 '):
+                prefix_list.append('받침 없거나 ㄹㅆㅄ 받침')
+                s = s[len('받침이 없거나 ‘ㄹ’, ‘ㅆ’, ‘ㅄ’ 받침인 '):]
+            elif s.startswith('받침 없는 '):
+                prefix_list.append('받침 없음')
+                s = s[len('받침 없는 '):]
+            elif s.startswith('받침 있는 '):
+                prefix_list.append('받침 있음')
+                s = s[len('받침 있는 '):]
+
+            prefix_found = False
+            if '뒤에 붙여 ' in s:
+                s = s.split(' 뒤에 붙여 ')[0]
+                prefix_found = True
+            elif '에 붙여 쓴다' in s:
+                s = s.split('에 붙여 쓴다')[0]
+                prefix_found = True
+
+            if prefix_found:
+                if s == '말':
+                    prefix_list.append('체언')
+                    used = True
+                elif '명사' in s:
+                    prefix_list.append('명사')
+                    used = True
+                elif '체언' in s:
+                    prefix_list.append('체언')
+                    used = True
+                elif '부사어' in s:
+                    prefix_list.append('부사어')
+                    used = True
+                elif '조사' in s:
+                    prefix_list.append('조사')
+                    used = True
+            elif s.endswith(' 온다'):
+                continue
+            elif s.endswith(' 쓸 수 있다'):
+                continue
+            elif s.endswith('로 쓴다'):
+                continue
+            elif s.endswith('활용을 한다'):
+                continue
+            elif s.endswith('잘 쓰지 않는다'):
+                continue
+            elif s.endswith('함께 쓴다'):
+                continue
+
+            if not used:
+                print('사용되지 않은 조사 참고: %s (%s)' % (clue,s))
+
+        found = False
+        for prefix in prefix_list:
+            if prefix in ['명사', '대명사', '수사']:
+                found = True
+
+        if not found:
+            prefix_list = []
+        else:
+            # remove duplicates
+            new_prefix_list = []
+            for prefix in prefix_list:
+                # 형태가 다를 수는 있어도 명사만 받는 조사는 없다
+                if prefix in ['명사']:
+                    if '체언' not in new_prefix_list:
+                        new_prefix_list.append('체언')
+            prefix_list = new_prefix_list
+            prefix_list.sort()
+
+        return prefix_list
+
 if __name__ == '__main__':
     if len(sys.argv) != 2:
-        print('Usage: %s <entries_dir>')
+        print('Usage: %s <filename.yaml>')
         sys.exit(1)
 
-    entries_dir = sys.argv[1]
-    processor = ProcessYamlDocs(entries_dir)
+    yaml_filename = sys.argv[1]
+    processor = ProcessYamlDocs(yaml_filename)
     processor.run()
